| Title: | Efficient Block Designs for 3-Level Factorial Experiments in Block Size 3 |
|---|---|
| Description: | Provides functions to construct efficient block designs for 3-level factorial experiments in block size 3. The designs ensure the estimation of all main effects and two-factor interactions in minimum number of replications. For more details, see Dey and Mukerjee (2012) <doi:10.1016/j.spl.2012.06.014> and Dash, S., Parsad, R. and Gupta, V.K. (2013) <doi:10.1007/s40003-013-0059-5>. |
| Authors: | Sunil Kumar Yadav [aut], Sukanta Dash [aut, cre] |
| Maintainer: | Sukanta Dash <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-05-31 07:15:25 UTC |
| Source: | https://github.com/cran/bdf3 |
Constructs efficient block designs for 3-level factorial experiments in block size 3, ensuring estimation of all main effects (with full efficiency) and two-factor interactions.
bdf3.mef(n_factors, show_efficiency = TRUE)bdf3.mef(n_factors, show_efficiency = TRUE)
n_factors |
An integer specifying the number of factors. |
show_efficiency |
Logical. If |
This function generates efficient block designs for 3-level factorial experiments in block size 3. The resulting designs allow estimation of all main effects (with full efficiency) and two-factor interactions in minimum number of replications.
A list containing:
blocks |
The chosen principal blocks |
confounded_effects |
The confounded main effects and two-factor interactions |
efficiency_factors |
Efficiency factors of all main effects and two-factor interactions (if |
design |
The final block design for the given number of factors |
Dey, A. and Mukerjee, R. (2012). Efficiency factors for natural contrasts in partially confounded factorial designs. Statistics and Probability Letters, 82(12), 2180–2188. <doi:10.1016/j.spl.2012.06.014>
Dash, S., Parsad, R. and Gupta, V. K. (2013). Row–column designs for 2^n factorial 2-colour microarray experiments for estimation of main effects and two-factor interactions with orthogonal parameterization. Agricultural Research, 2(2), 172-182. <doi:10.1007/s40003-013-0059-5>
bdf3.mef(2)bdf3.mef(2)
Constructs efficient block designs for 3-level factorial experiments in block size 3, ensuring estimation of all main effects and two-factor interactions.
bdf3.mep(n_factors, show_efficiency = TRUE)bdf3.mep(n_factors, show_efficiency = TRUE)
n_factors |
An integer specifying the number of factors. |
show_efficiency |
Logical. If |
This function generates efficient block designs for 3-level factorial experiments in block size 3. The resulting designs allow estimation of all main effects and two-factor interactions in minimum number of replications.
A list containing:
blocks |
The chosen principal blocks |
confounded_effects |
The confounded main effects and two-factor interactions |
efficiency_factors |
Efficiency factors of all main effects and two-factor interactions (if |
design |
The final block design for the given number of factors |
Dey, A. and Mukerjee, R. (2012). Efficiency factors for natural contrasts in partially confounded factorial designs. Statistics and Probability Letters, 82(12), 2180–2188. <doi:10.1016/j.spl.2012.06.014>
Dash, S., Parsad, R. and Gupta, V. K. (2013). Row–column designs for 2^n factorial 2-colour microarray experiments for estimation of main effects and two-factor interactions with orthogonal parameterization. Agricultural Research, 2(2), 172-182. <doi:10.1007/s40003-013-0059-5>
bdf3.mep(2)bdf3.mep(2)